==> dde-file-manager_5.6.4.orig.tar.xz: dde-file-manager-5.6.4/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Upłynął limit czasu uwierzytelniania</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Dysk jest zajęty, nie można teraz odmontować</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Dysk jest zajęty, nie można go teraz wysunąć</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Urządzenie jest zajęte, nie można go teraz wysunąć</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Urządzenie jest zajęte, nie można go teraz wyjąć</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>Volumen %1</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Nieznany</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Urządzenie nie zostało bezpiecznie usunięte</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Kliknij „Bezpieczne usuwanie”, a następnie odłącz go następnym razem</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Nie można odmontować urządzenia</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Dysk został zamontowany przez użytkownika &quot;%1&quot;, nie możesz go wymontować.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Nie można odnaleźć podpiętego urządzenia</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Dyski</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Dysk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Usuń wszystko</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Urządzenie zostało bezpiecznie usunięte</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Odmowa dostępu</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Nie masz uprawnień do dostępu do tego katalogu</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Skanowanie urządzenia, zatrzymać?</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Potwierdź</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>Stop</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.6.9.orig.tar.xz: dde-file-manager-5.6.9/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Upłynął limit czasu uwierzytelniania</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Dysk jest zajęty, nie można teraz odmontować</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Dysk jest zajęty, nie można go teraz wysunąć</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Urządzenie jest zajęte, nie można go teraz wysunąć</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Urządzenie jest zajęte, nie można go teraz wyjąć</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>Volumen %1</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Nieznany</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Urządzenie nie zostało bezpiecznie usunięte</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Kliknij „Bezpieczne usuwanie”, a następnie odłącz go następnym razem</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Nie można odmontować urządzenia</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Dysk został zamontowany przez użytkownika &quot;%1&quot;, nie możesz go odmontować.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Nie można odnaleźć podpiętego urządzenia</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Dyski</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Dysk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Usuń wszystko</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Urządzenie zostało bezpiecznie usunięte</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Odmowa dostępu</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Nie posiadasz uprawnień dostępu do tego katalogu</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Skanowanie urządzenia, zatrzymać?</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Potwierdź</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>Stop</translation>
    </message>
</context>
</TS>
